@@ -566,8 +566,8 @@ func TestMakePrivateService(t *testing.T) {
 		},
 		want: &corev1.Service{
 			ObjectMeta: metav1.ObjectMeta{
-				Namespace:    "melon",
-				GenerateName: "collie-",
+				Namespace: "melon",
+				Name:      "collie-private",
 				Labels: map[string]string{
 					// Those should be propagated.
 					serving.RevisionLabelKey:  "collie",
@@ -603,11 +603,11 @@ func TestMakePrivateService(t *testing.T) {
 			},
 		},
 	}, {
-		name: "HTTP2",
+		name: "HTTP2 and long",
 		sks: &v1alpha1.ServerlessService{
 			ObjectMeta: metav1.ObjectMeta{
 				Namespace: "siamese",
-				Name:      "dream",
+				Name:      "dream-tonight-cherub-rock-mayonaise-hummer-disarm-rocket-soma-quiet",
 				UID:       "1988",
 				// Those labels are propagated from the Revision->PA.
 				Labels: map[string]string{
@@ -627,13 +627,13 @@ func TestMakePrivateService(t *testing.T) {
 		},
 		want: &corev1.Service{
 			ObjectMeta: metav1.ObjectMeta{
-				Namespace:    "siamese",
-				GenerateName: "dream-",
+				Namespace: "siamese",
+				Name:      "dream-tonight-cherub-ro9598b55360c44122a4442ce54caa8619-private",
 				Labels: map[string]string{
 					// Those should be propagated.
 					serving.RevisionLabelKey:  "dream",
 					serving.RevisionUID:       "1988",
-					networking.SKSLabelKey:    "dream",
+					networking.SKSLabelKey:    "dream-tonight-cherub-rock-mayonaise-hummer-disarm-rocket-soma-quiet",
 					networking.ServiceTypeKey: "Private",
 				},
 				Annotations: map[string]string{
@@ -642,7 +642,7 @@ func TestMakePrivateService(t *testing.T) {
 				OwnerReferences: []metav1.OwnerReference{{
 					APIVersion:         v1alpha1.SchemeGroupVersion.String(),
 					Kind:               "ServerlessService",
-					Name:               "dream",
+					Name:               "dream-tonight-cherub-rock-mayonaise-hummer-disarm-rocket-soma-quiet",
 					UID:                "1988",
 					Controller:         ptr.Bool(true),
 					BlockOwnerDeletion: ptr.Bool(true),
